OC.L10N.register(
    "settings",
    {
    "Private" : "خصوصی",
    "Only visible to people matched via phone number integration through Talk on mobile" : "نمایان تنها برای افرادی که با یکپارچگی شماره تلفن از طریق Talk روی تلفن همراه مطابقند",
    "Local" : "محلی",
    "Only visible to people on this instance and guests" : "نمایان تنها برای افراد روی این نمونه و میهانان",
    "Federated" : "همگانی",
    "Only synchronize to trusted servers" : "هم‌گام سازی تنها با کارسازهای مورد اعتماد",
    "Published" : "منتشر شده",
    "Synchronize to trusted servers and the global and public address book" : "هم‌گام سازی با کارسازهای مورد اعتماد و دفترچه نشانی‌های عمومی",
    "Verify" : "تأیید",
    "Verifying …" : "تأیید کردن…",
    "Unable to change password" : "نمی‌توان رمز را تغییر داد",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Groups" : "گروه ها",
    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
    "{actor} added you to group {group}" : "{actor} به گروه {group} افزودتان",
    "You added {user} to group {group}" : "{user} را به گروه {group} افزودید",
    "{actor} added {user} to group {group}" : "{actor} کاربر {user} را به گروه {group} افزود",
    "An administrator added you to group {group}" : "مدیری به گروه {group} افزودتان",
    "An administrator added {user} to group {group}" : "مدیری {user}  را به گروه {group} افزود",
    "{actor} removed you from group {group}" : "{actor} از گروه {group} برداشتتان",
    "You removed {user} from group {group}" : "{user} را از گروه {group} برداشتید",
    "{actor} removed {user} from group {group}" : "{actor} کاربر {user} را از گروه {group} برداشت",
    "An administrator removed you from group {group}" : "مدیری از گروه {group} برداشتتان",
    "An administrator removed {user} from group {group}" : "مدیری {user} را از گروه {group} برداشت",
    "Your <strong>group memberships</strong> were modified" : "<strong>عضویتتان در گروه</strong> تغییر یافت",
    "{actor} changed your password" : "{actor} گذرواژه‌تان را تغییر داد",
    "You changed your password" : "گذرواژه‌تان را تغییر دادید",
    "Your password was reset by an administrator" : "گذرواژه‌تان به دست مدیری بازنشانی شد",
    "Your password was reset" : "گذرواژه‌تان بازنشانی شد",
    "{actor} changed your email address" : "{actor} نشانی رایانامه‌تان را تغییر داد",
    "You changed your email address" : "نشانی رایانامه‌تان را تغییر دادید",
    "Your email address was changed by an administrator" : "نشانی رایانامه‌تان به دست مدیری عوض شد",
    "You created an app password for a session named \"{token}\"" : "You created an app password for a session named \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "An administrator created an app password for a session named \"{token}\"",
    "You deleted app password \"{token}\"" : "گذرواژهٔ کارهٔ «{token}» را حذف کردید",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "نام گذرواژهٔ کارهٔ «{token}» را به «{newToken}» تغییر دادید",
    "You granted filesystem access to app password \"{token}\"" : "دسترسی به سامانه‌پرونده را به گذرواژهٔ کارهٔ «{token}» اعطا کردید",
    "You revoked filesystem access from app password \"{token}\"" : "دسترسی به سامانه‌پرونده را از گذرواژهٔ کارهٔ «{token}» گرفتید",
    "Security" : "امنیت",
    "You successfully logged in using two-factor authentication (%1$s)" : "شما با موفقیت با استفاده از تأیید هویت دو عاملی وارد سیستم شدید(%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "تلاش برای ورود به سیستم با استفاده از تأیید هویت دو عاملی انجام نشد (%1$s)",
    "Remote wipe was started on %1$s" : "پاک کردن از راه دور شروع شد %1$s",
    "Remote wipe has finished on %1$s" : "پاک کردن از راه دور به پایان رسید%1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>پسورد</strong> و یا  <strong>پست الکترونیک</strong> شما ویراش شد.",
    "Settings" : "تنظیمات",
    "Could not remove app." : "امکان حذف برنامه وجود ندارد.",
    "Could not update app." : "برنامه را نمی توان به روزرسانی کرد .",
    "Wrong password" : "رمز عبور اشتباه است",
    "Unable to change personal password" : "نمی‌توان گذرواژه شخصی را تغییر داد",
    "Saved" : "ذخیره شد",
    "Unable to change password. Password too long." : "Unable to change password. Password too long.",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Wrong admin recovery password. Please check the password and try again." : "رمز مدیریتی بازیابی غلط است. لطفاً رمز را کنترل کرده و دوباره امتحان نمایید.",
    "Administrator documentation" : "مستندات مدیر",
    "User documentation" : "مستندات کاربر",
    "Nextcloud help overview" : "نمای کلی راهنمای نکست‌کلود",
    "Invalid SMTP password." : "گذرواژه SMTP نامعتبر است.",
    "Email setting test" : "تست تنظیم پست الکترونیک",
    "Well done, %s!" : "انجام شد،%s!",
    "If you received this email, the email configuration seems to be correct." : "اگر این پست الکترونیک را دریافت کردید ، پیکربندی ایمیل درست است.",
    "Email could not be sent. Check your mail server log" : "پست الکترونیک قابل ارسال نیست. ورود به سیستم سرور پست الکترونیک خود را بررسی کنید",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ارسال پست الکترونیک با خطا مواجه شد، لطفاً تنظیمات خود را مورد بازبینی قرار دهید. (خطا:%s)",
    "Disabled accounts" : "حساب‌های غیرفعال",
    "Invalid mail address" : "آدرس ایمیل نامعتبر است",
    "Settings saved" : "تنظیمات ذخیره شد",
    "Unable to change full name" : "امکان تغییر نام کامل وجود ندارد",
    "Unable to change email address" : "تغییرات پست الکترونیک امکان‌پذیر نیست",
    "Unable to set invalid phone number" : "Unable to set invalid phone number",
    "Unable to set invalid website" : "Unable to set invalid website",
    "Some account data was invalid" : "Some account data was invalid",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "به منظور تأیید حساب توییتر خود ، توییت زیر را در توییتر قرار دهید (لطفاً آن را بدون هیچگونه فاصله بین خطوط ارسال کنید):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "برای تأیید وب سایت خود ، مطالب زیر را در ریشه وب خود در سایت ذخیره کنید:\n '.well-known/CloudIdVerificationCode.txt' \n(لطفاً اطمینان حاصل کنید که تمام متن در یک خط است):",
    "%1$s changed your password on %2$s." : "%1$s رمزعبور خود را تغییر داد به %2$s",
    "Your password on %s was changed." : "پسورد شما به %s تغییر یافت",
    "Your password on %s was reset by an administrator." : "رمز عبور شما توسط یک مدیر به %s تنظیم مجدد شد.",
    "Your password on %s was reset." : "Your password on %s was reset.",
    "Password for %1$s changed on %2$s" : "رمزعبور از %1$sبه %2$s تغییر یافت",
    "Password changed for %s" : "پسور به %s تغییر یافت",
    "If you did not request this, please contact an administrator." : "اگر این درخواست را نکردید ، با یک مدیر تماس بگیرید.",
    "Your email address on %s was changed." : "پست الکترونیک شما به %s تغییر یافت",
    "Your email address on %s was changed by an administrator." : "پست الکترونیک شما توط یک مدیر به %s  تنظیم مجدد شد.",
    "Email address for %1$s changed on %2$s" : "پست الکترونیک از %1$s به %2$s تغییر یافت.",
    "Email address changed for %s" : "پست الکترونیک به %s تغییر یافت",
    "The new email address is %s" : "آدرس پست الکترونیک جدید %s می باشد.",
    "Your %s account was created" : "حساب کاربری شما  %s ایجاد شد",
    "Welcome aboard" : "به داخل خوش آمدید",
    "Welcome aboard %s" : "به داخل خوش آمدید %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s به حساب کاربری خود خوش آمدید ،شما می توانید اضافه کنید ، محافظت و اطلاعات خود را اشتراک به بگذارید.",
    "Set your password" : "کلمه ی عبور خود را تنظیم کنید",
    "Go to %s" : "برو به %s",
    "Install Client" : "قسمت مشتری را نصب کنید",
    "Apps" : "برنامه ها",
    "Personal" : "شخصی",
    "Administration" : "مدیریت",
    "Users" : "کاربران",
    "Additional settings" : "تنظیمات اضافی",
    "Artificial Intelligence" : "هوش مصنوعی",
    "Administration privileges" : "اجازه‌های مدیریتی",
    "Groupware" : "کار گروهی",
    "Overview" : "نمای کلّی",
    "Basic settings" : "تنظیمات پایه",
    "Sharing" : "اشتراک گذاری",
    "Availability" : "در دسترس بودن",
    "Calendar" : "تقویم",
    "Personal info" : "اطّلاعات شخصی",
    "Mobile & desktop" : "همراه و میزکار",
    "Email server" : "سرور ایمیل",
    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
    "Background jobs" : "کارهای پس‌زمینه",
    "Unlimited" : "نامحدود",
    "Verifying" : "تآیید کردن",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
    "Disabled" : "غیرفعال شده",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Supported" : "پشتیبانی شده",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation.",
    "PHP configuration option \"output_buffering\" must be disabled" : "گزینه «output_buffering» تنظیمات پی‌اچ‌پی باید غیرفعال شود",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
    "Architecture" : "Architecture",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
    "Profile information" : "اطلاعات نمایه",
    "Nextcloud settings" : "تنظیمات نکست کلود",
    "Task:" : "Task:",
    "Machine translation" : "Machine translation",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
    "Image generation" : "Image generation",
    "Text processing" : "Text processing",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
    "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
    "None" : "هیچ‌کدام",
    "Unable to modify setting" : "Unable to modify setting",
    "Allow apps to use the Share API" : "اجازه ی برنامه ها برای استفاده از API اشتراک گذاری",
    "Allow resharing" : "مجوز اشتراک گذاری مجدد",
    "Allow sharing with groups" : "اشتراک گذاری با گروه ها مجاز است",
    "Restrict users to only share with users in their groups" : "محدود کردن کاربران برای اشتراک‌گذاری تنها میان کاربران گروه خود",
    "Allow users to share via link and emails" : "Allow users to share via link and emails",
    "Allow public uploads" : "اجازه بارگذاری عمومی",
    "Always ask for a password" : "رمز عبور را همیشه بپرسید.",
    "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور",
    "Set default expiration date for shares" : "تاریخ انقضا پیش فرض را برای اشتراک گذاری تعیین کنید",
    "Enforce expiration date" : "اعمال تاریخ اتمام اشتراک گذاری",
    "Set default expiration date for shares to other servers" : "Set default expiration date for shares to other servers",
    "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user.",
    "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
    "This text will be shown on the public link upload page when the file list is hidden." : "این متن هنگام پنهان کردن لیست پرونده در صفحه بارگذاری پیوند عمومی نشان داده می شود.",
    "Default share permissions" : "مجوزهای اشتراکی پیش فرض",
    "Two-Factor Authentication" : "احراز هویت دو عاملی",
    "Enforce two-factor authentication" : "احراز هویت دو عاملی",
    "Limit to groups" : "محدود کردن به گروه‌ها",
    "Enforcement of two-factor authentication can be set for certain groups only." : "اجبار به احراز هویت دو عاملی فقط می‌تواند برای گروه‌هایی خاص تنظیم شود.",
    "Two-factor authentication is enforced for all members of the following groups." : "Two-factor authentication is enforced for all members of the following groups.",
    "Enforced groups" : "گروه‌های اجباری",
    "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
    "Excluded groups" : "گروه‌های مستثنی",
    "Save changes" : "ذخیرهٔ تغییرات",
    "Update to {update}" : "به‌روز رسانی به {update} ",
    "Remove" : "برداشتن",
    "Disable" : "غیرفعال",
    "Featured" : "برگزیده",
    "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه‌های برگزیده توسط و در داخل جامعه توسعه داده می‌شوند. این برنامه‌ها، عملکردهای مرکزی را ارائه می‌دهند و برای استفاده نهایی آماده هستند.",
    "All apps are up-to-date." : "تمامی کاره‌ها به‌روزند.",
    "Icon" : "Icon",
    "Name" : "نام",
    "Version" : "نسخه",
    "Level" : "مرحله",
    "Actions" : "کنش‌ها",
    "Results from other categories" : "نتایج از دیگر دسته‌ها",
    "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
    "Disable all" : "از کار انداختن همه",
    "_%n app has an update available_::_%n apps have an update available_" : ["۱ کاره به‌روز رسانی دارد","%n کاره به‌روز رسانی دارند"],
    "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
    "Loading" : "Loading",
    "Description" : "شرح",
    "Details" : "جزییات",
    "All" : "همه",
    "Limit app usage to groups" : "محدودیت استفاده از کاره به گروه‌ها",
    "No results" : "بدون نتیجه",
    "Update to {version}" : "به‌روز رسانی به {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
    "Author" : "نویسنده",
    "Categories" : "دسته‌ها",
    "Resources" : "منابع",
    "Documentation" : "مستندسازی",
    "Report a bug" : "گزارش یک خطا",
    "Request feature" : "درخواست ویژگی",
    "Ask questions or discuss" : "پرسش یا بحث",
    "Rate" : "رتبه‌بندی",
    "View in store" : "نمایش در فروشگاه",
    "Visit website" : "سر زدن به پایگاه وب",
    "Admin documentation" : "مستندات مدیر",
    "Developer documentation" : "مستندات توسعه‌دهندگان",
    "Changelog" : "تغییر",
    "Marked for remote wipe" : "علامت خورده برای زودون دوردست",
    "Device settings" : "تنظیمات افزاره",
    "Allow filesystem access" : "اجازهٔ دسترسی به سامانه‌پرونده",
    "Rename" : "تغییرنام",
    "Revoke" : "لغو",
    "Wipe device" : "حذف دستگاه",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revoking this token might prevent the wiping of your device if it has not started the wipe yet.",
    "Google Chrome for Android" : "کروم گوگل برای اندروید",
    "{productName} iOS app" : "کارهٔ iOS {productName}",
    "{productName} Android app" : "کارهٔ اندرویدی {productName}",
    "{productName} Talk for iOS" : "صحبت {productName} برای iOS",
    "{productName} Talk for Android" : "صحبت {productName} برای اندروید",
    "This session" : "این نشست",
    "Device" : "افزاره",
    "Last activity" : "آخرین فعّالیت",
    "Devices & sessions" : "دستگاه ها و نشست ها",
    "Web, desktop and mobile clients currently logged in to your account." : "لیست دستگاه ها و نشست های فعال وارد شده با اکانت شما",
    "App name" : "نام برنامه",
    "Create new app password" : "ساختن رمزعبور برنامه جدید ",
    "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
    "Login" : "ورود",
    "Password" : "گذرواژه",
    "Show QR code for mobile apps" : "نمایش کد QR برای برنامه های تلفن همراه",
    "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information.",
    "Last job execution ran {time}. Something seems wrong." : "آخرین کار در {time} اجرا شد. به نظر چیزی اشتباه است.",
    "Last job ran {relativeTime}." : "آخرین کار در {time} اجرا شد.",
    "Background job did not run yet!" : "هنوز کار پس‌زمینه‌ای اجار نشده!",
    "AJAX" : "ای‌جکس",
    "Webcron" : "وب‌کرون",
    "Cron (Recommended)" : "کرون (پیشنهادی)",
    "Use system cron service to call the cron.php file every 5 minutes." : "برای تماس با پرونده cron.php هر 5 دقیقه یکبار از سرویس cron system استفاده کنید.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
    "Unable to update background job mode" : "ناتوان در به‌روز رسانی حالت کار پس‌زمینه",
    "Profile" : "نمایه",
    "Enable" : "فعال",
    "Unable to update profile default setting" : "ناتوان در به‌روز رسانی تنظیمات پیش‌گزیدهٔ نمایه",
    "Server-side encryption" : "رمزگذاری سمت سرور",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "\"رمزگذاری سمت سرور\" امکان رمزگذاری پرونده های آپلود شده در این سرور را امکان پذیر می کند. که با محدودیت هایی مانند مجازات عملکرد همراه است ، بنابراین در صورت لزوم فعال کنید.",
    "Enable server-side encryption" : "فعال‌سازی رمزگذاری سمت-سرور",
    "Please read carefully before activating server-side encryption:" : "Please read carefully before activating server-side encryption:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "پس از فعال سازی رمزگذاری ، تمام پرونده های بارگذاری شده از آن نقطه به سرور بارگیری می شوند و در حالت آماده به کار روی سرور رمزگذاری می شوند. غیرفعال کردن رمزگذاری در صورتی که ماژول رمزگذاری فعال از آن عملکرد پشتیبانی کند، در تاریخ بعد امکان پذیر است و کلیه پیش شرط ها (به عنوان مثال تنظیم کلید بازیابی) برآورده می شوند.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "رمزگذاری به تنهایی امنیت سیستم را تضمین نمی کند. لطفاً برای اطلاعات بیشتر درباره چگونگی عملکرد برنامه رمزگذاری و موارد استفاده از پشتیبانی ، به اسناد مراجعه کنید.",
    "Be aware that encryption always increases the file size." : "توجه داشته باشید که همواره رمزگذاری حجم فایل را افزایش خواهد داد.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "همیشه خوب است که از داده های خود نسخه پشتیبان تهیه کنید ، در صورت رمزگذاری مطمئن شوید که از کلیدهای رمزنگاری به همراه داده خود نسخه پشتیبان تهیه کنید.",
    "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
    "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
    "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
    "Unable to update server side encryption config" : "Unable to update server side encryption config",
    "Cancel" : "منصرف شدن",
    "Confirm" : "تأیید",
    "Submit" : "ارسال",
    "Rename group" : "Rename group",
    "Remove group" : "برداشتن گروه",
    "Current password" : "گذرواژه کنونی",
    "New password" : "گذرواژه جدید",
    "Change password" : "تغییر گذر واژه",
    "Your profile picture" : "نگارهٔ نمایه‌تان",
    "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
    "Choose profile picture from Files" : "تصویر نمایه‌تان را از پرونده‌ها انتخاب کنید",
    "Remove profile picture" : "برداشتن نگارهٔ نمایه",
    "The file must be a PNG or JPG" : "The file must be a PNG or JPG",
    "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
    "Set as profile picture" : "به عنوان عکس نمایه تنظیم کنید",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "لطفاً توجه داشته باشید که ممکن است تا 24 ساعت طول بکشد تا عکس نمایه شما در همه جا به روز شود.",
    "Choose your profile picture" : "عکس نمایهٔ خود را انتخاب کنید",
    "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
    "Error setting profile picture" : "خطا در تنظیم عکس نمایه",
    "Error cropping profile picture" : "خطا در برش عکس نمایه",
    "Error saving profile picture" : "خطا در ذخیره تصویر نمایه",
    "Error removing profile picture" : "خطا در حذف عکس نمایه",
    "Your biography" : "بیوگرافی شما",
    "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
    "You are using <strong>{usage}</strong>" : "فضای مورد استفاده: <strong>{usage}</strong>",
    "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "شما در حال استفادهٔ <strong>{usage}</strong> از <strong>{totalSpace}</strong> (<strong>{usageRelative}٪</strong>) فضا هستید",
    "Your full name" : "Your full name",
    "Primary email for password reset and notifications" : "ایمیل اصلی برای بازیابی رمز عبور و دریافت اعلان ها",
    "Email options" : "Email options",
    "Remove primary email" : "Remove primary email",
    "Delete email" : "Delete email",
    "This address is not confirmed" : "This address is not confirmed",
    "Unset as primary email" : "Unset as primary email",
    "Set as primary email" : "Set as primary email",
    "Additional email address {index}" : "Additional email address {index}",
    "Unable to delete primary email address" : "Unable to delete primary email address",
    "Unable to update primary email address" : "Unable to update primary email address",
    "Unable to add additional email address" : "Unable to add additional email address",
    "Unable to update additional email address" : "Unable to update additional email address",
    "Unable to delete additional email address" : "Unable to delete additional email address",
    "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
    "Your handle" : "Your handle",
    "Your headline" : "عنوان سرصفحه",
    "Help translate" : "به ترجمه آن کمک کنید",
    "Unable to update language" : "Unable to update language",
    "No language set" : "زبانی تنظیم نشده است.",
    "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
    "Unable to update locale" : "Unable to update locale",
    "No locale set" : "تنظیمات locale انجام نشده است",
    "Your city" : "شهر شما",
    "Your organisation" : "نام سازمان",
    "Your phone number" : "شماره تلفن شما",
    "Edit your Profile visibility" : "ویرایش امکان مشاهده پروفایل",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "ملاک عمل، تنظیمات با محدودیت بالاتر است که اعمال می شوند. برای مثال، اگر \"قابلیت دیده شدن\" در وضعیت \"نمایش برای همه\" تنظیم شده باشد و \"محدوده دیده شدن\" در وضعیت \"خصوصی\" تنظیم شده باشد، تنظیم به وضعیت \"خصوصی\" که محدودیت بیشتری اعمال میکند اعمال خواهد شد.",
    "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
    "Your role" : "نقش شما",
    "Your website" : "وبسایت شما",
    "No {property} set" : "No {property} set",
    "Unable to update {property}" : "Unable to update {property}",
    "Change scope level of {property}, current scope is {scope}" : "Change scope level of {property}, current scope is {scope}",
    "Unable to update federation scope of the primary {property}" : "Unable to update federation scope of the primary {property}",
    "Unable to update federation scope of additional {property}" : "Unable to update federation scope of additional {property}",
    "Add additional email" : "Add additional email",
    "Add" : "افزودن",
    "Create" : "ایجاد",
    "Change" : "تغییر",
    "Delete" : "حذف",
    "Reshare" : "بازهم‌رسانی",
    "No accounts" : "حسابی وجود ندارد",
    "Default language" : "زبان پیش فرض",
    "Common languages" : "زبانهای رایج",
    "Other languages" : "Other languages",
    "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
    "Display name" : "نمایش نام",
    "Either password or email is required" : "Either password or email is required",
    "Password (required)" : "Password (required)",
    "Email (required)" : "Email (required)",
    "Email" : "ایمیل",
    "Quota" : "سهم",
    "Language" : "زبان",
    "Set default language" : "Set default language",
    "Manager" : "Manager",
    "Total rows summary" : "خلاصه کل ردیف ها",
    "Scroll to load more rows" : "Scroll to load more rows",
    "Avatar" : "آواتار",
    "Account name" : "Account name",
    "Group admin for" : "مدیر گروه برای",
    "Storage location" : "محل ذخیره سازی",
    "Last login" : "آخرین ورود",
    "Account actions" : "اقدامات حساب",
    "Password or insufficient permissions message" : "Password or insufficient permissions message",
    "Set the language" : "Set the language",
    "{size} used" : "{size} مورد استفاده",
    "Resend welcome email" : "ارسال ایمیل خوش آمدید",
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
    "Remote wipe of devices" : "پاک کردن از راه دور دستگاه ها",
    "Wipe {userid}'s devices" : "دستگاه های {userid} را پاک کنید",
    "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "حساب {userid} را با تمام پرونده های شخصی ، داده های برنامه و غیره به طور کامل حذف کنید.",
    "Account deletion" : "حذف حساب کاربری",
    "Delete {userid}'s account" : "حساب {userid} را حذف کنید",
    "Display name was successfully changed" : "Display name was successfully changed",
    "Password was successfully changed" : "Password was successfully changed",
    "Email was successfully changed" : "Email was successfully changed",
    "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
    "Done" : "انجام شد",
    "Edit" : "ویرایش",
    "Visibility" : "Visibility",
    "Show language" : "Show language",
    "Show storage path" : "نمایش مسیر ذخیره سازی",
    "Show last login" : "نمایش آخرین ورود",
    "Sorting" : "مرتب سازی",
    "Send email" : "ارسال ایمیل",
    "Defaults" : "Defaults",
    "Default quota" : "سهمیه پیش فرض",
    "Select default quota" : "سهمیه پیش فرض را انتخاب کنید",
    "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
    "Add WebAuthn device" : "Add WebAuthn device",
    "Please authorize your WebAuthn device." : "Please authorize your WebAuthn device.",
    "Adding your device …" : "Adding your device …",
    "Server error while trying to complete WebAuthn device registration" : "Server error while trying to complete WebAuthn device registration",
    "Unnamed device" : "Unnamed device",
    "Passwordless Authentication" : "Passwordless Authentication",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
    "No devices configured." : "No devices configured.",
    "The following devices are configured for your account:" : "The following devices are configured for your account:",
    "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
    "You need to enable the File sharing App." : "You need to enable the File sharing App.",
    "All accounts" : "همهٔ حساب‌ها",
    "Admins" : "مدیران",
    "Group name" : "نام گروه",
    "Sending…" : "در حال ارسال",
    "Email sent" : "ایمیل ارسال شد",
    "Location" : "مکان",
    "Profile picture" : "تصویر پروفایل",
    "About" : "درباره",
    "Full name" : "نام کامل",
    "Additional email" : "Additional email",
    "Headline" : "عنوان",
    "Organisation" : "سازمان",
    "Phone number" : "شماره تلفن",
    "Role" : "نقش",
    "Fediverse (e.g. Mastodon)" : "Fediverse (e.g. Mastodon)",
    "Website" : "وب‌ سایت",
    "Profile visibility" : "امکان دیده شدن پروفایل",
    "Locale" : "محل",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
    "Your apps" : "برنامه‌های شما",
    "Active apps" : "برنامه‌های فعال",
    "Disabled apps" : "برنامه‌های غیرفعال",
    "Updates" : "به روز رسانی ها",
    "App bundles" : "بسته های برنامه",
    "Featured apps" : "برنامه‌های برگزیده",
    "Supported apps" : "Supported apps",
    "Show to everyone" : "نمایش به همه",
    "Show to logged in accounts only" : "فقط به حساب‌هایی که وارد شده‌اند نمایش یابد",
    "Hide" : "پنهان کردن",
    "Download and enable" : "بارگیری و فعال سازی",
    "Allow untested app" : "Allow untested app",
    "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
    "Never" : "هرگز",
    "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما باید به روز شود. شما پس از 5 ثانیه به صفحه بروزرسانی هدایت می شوید.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
    "Do you really want to wipe your data from this device?" : "واقعاً می خواهید داده‌هایتان را از این افزاره بزدایید؟",
    "Confirm wipe" : "تأیید زودن",
    "Error while wiping the device with the token" : "هنگام پاک کردن وسیله با نشانه خطا رخ داد",
    "Error while updating device token name" : "هنگام بروزرسانی نام کد وسیله خطایی رخ داد",
    "Error while updating device token scope" : "هنگام بروزرسانی دامنه توکن وسیله خطایی رخ داد",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "خطا",
    "Forum" : "انجمن",
    "Nextcloud help & privacy resources" : "منابع راهنما و حریم شخصی نکست‌کلود",
    "Legal notice" : "توصیهٔ حقوقی",
    "Privacy policy" : "سیاست محرمانگی",
    "None/STARTTLS" : "None/STARTTLS",
    "SSL" : "SSL",
    "Open documentation" : "بازکردن مستند",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
    "Send mode" : "حالت ارسال",
    "Encryption" : "رمزگذاری",
    "Sendmail mode" : "حالت Sendmail",
    "From address" : "آدرس فرستنده",
    "Server address" : "آدرس سرور",
    "Port" : "درگاه",
    "Authentication" : "احراز هویت",
    "Authentication required" : "احراز هویت مورد نیاز است",
    "Credentials" : "اعتبارهای",
    "SMTP Password" : "رمز عبور SMTP",
    "Save" : "ذخیره",
    "Test and verify email settings" : "Test and verify email settings",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید",
    "Reasons to use Nextcloud in your organization" : "دلایلی برای استفاده از نکست‌کلود در سازمان شما",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "توسعه یافته توسط {communityopen} انجمن نکست کلود {linkclose}، {githubopen} کد منبع {linkclose} تحت مجوز {licenseopen}AGPL{linkclose}است. ",
    "Like our Facebook page" : "پسندیدن صفحه فیس بوک ما",
    "Follow us on Twitter" : "ما را در توییتر دنبال کنید",
    "Follow us on Mastodon" : "ما را در ماستودون دنبال کنید",
    "Check out our blog" : "وبلاگ ما را بررسی کنید",
    "Subscribe to our newsletter" : "مشترک شدن در خبرنامه ما",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
    "Use a second factor besides your password to increase security for your account." : "برای افزایش امنیت حساب کاربری خود ، از یک عامل دوم علاوه بر رمز عبور خود استفاده کنید.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
    "No user supplied" : "هیچ کاربری تعریف نشده است",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "لطفاً رمز عبور بازیابی مدیر را ارائه دهید. در غیر این صورت ، تمام داده های کاربر از بین می رود.",
    "Backend does not support password change, but the user's encryption key was updated." : " سرور از تغییرات گذرواژه پشتیبانی نمی کند، اما کلید رمزگذاری کاربر به روز شد.",
    "You need to set your user email before being able to send test emails. Go to %s for that." : "You need to set your user email before being able to send test emails. Go to %s for that.",
    "Invalid user" : "کاربر نامعتبر",
    "Your username is: %s" : "نام کاربری شما %s هست.",
    "Logged in user must be a subadmin" : "ورود به سیستم کاربر باید زیرمجموعه باشد",
    "A background job is pending that checks for user imported SSL certificates. Please check back later." : "A background job is pending that checks for user imported SSL certificates. Please check back later.",
    "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below.",
    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
    "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher.",
    "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher.",
    "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher.",
    "Speech-To-Text" : "Speech-To-Text",
    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "Speech-To-Text can be implemented by different apps. Here you can set which app should be used.",
    "None of your currently installed apps provide Speech-To-Text functionality" : "None of your currently installed apps provide Speech-To-Text functionality",
    "None of your currently installed apps provide Text processing functionality" : "None of your currently installed apps provide Text processing functionality",
    "Exclude groups from sharing" : "مستثنی شدن گروه ها از اشتراک گذاری",
    "These groups will still be able to receive shares, but not to initiate them." : "این گروه ها هنوز هم می توانند سهم دریافت کنند ، اما نه آنها را شروع کنند.",
    "Allow username autocompletion in share dialog and allow access to the system address book" : "Allow username autocompletion in share dialog and allow access to the system address book",
    "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system.",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "هنگامی که گروه ها انتخاب و حذف شدند ، از این منطق استفاده می کنند تا مشخص شود آیا کاربر 2FA اجباری دارد: اگر هیچ گروه انتخاب نشده باشند ، 2FA برای همه غیر از اعضای گروه های محروم امکان پذیر است. در صورت انتخاب گروه ها ، 2FA برای همه اعضای این گروه فعال است. اگر کاربر هر دو در یک گروه منتخب و مستثنی باشد ، انتخاب شده دارای اولویت است و 2FA اجرا می شود.",
    "{license}-licensed" : "دارای مجوز- {license}",
    "Username" : "نام کاربری",
    "Execute one task with each page loaded. Use case: Single user instance." : "اجرای یک وظیفه با هر بار شدن صفحه. مناسب نمونه‌های تک کاربره.",
    "cron.php is registered at a webcron service to call cron.php every 5 minutes over HTTP. Use case: Very small instance (1–5 users depending on the usage)." : "پروندهٔ cron.php ثبت شده در یک خدمت webcron برای فراخوانی هر ۵ دقیقه یک بار روی HTTP. مناسب برای نمونه‌های بسیار کوچک ( تا ۵ کاربر بسته به استفاده).",
    "The cron.php needs to be executed by the system user \"{user}\"." : "پروندهٔ cron.php باید به دست کاربر سامانه‌ای {user} قابل اجرا باشد.",
    "Enable or disable profile by default for new users." : "به یا از کار انداختن نمایه برای کاربران جدید به صورت پیش‌گزیده.",
    "Additional emails" : "Additional emails",
    "Enable Profile" : "فعال کردن پروفایل",
    "No users" : "No users",
    "Loading users …" : "Loading users …",
    "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list." : "List of users. This list is not fully rendered for performance reasons. The users will be rendered as you navigate through the list.",
    "New user" : "کاربر جدید",
    "Groups (required)" : "Groups (required)",
    "Set user groups" : "Set user groups",
    "Administered groups" : "Administered groups",
    "Set user as admin for …" : "Set user as admin for …",
    "Set user quota" : "Set user quota",
    "Add new user" : "Add new user",
    "Set user manager" : "Set user manager",
    "Username will be autogenerated" : "Username will be autogenerated",
    "Username (required)" : "Username (required)",
    "User backend" : "پشتیبان کاربر",
    "User actions" : "User actions",
    "Loading user …" : "Loading user …",
    "You do not have permissions to see the details of this user" : "شما مجوز دیدن جزئیات این کاربر را ندارید",
    "Add user to group" : "Add user to group",
    "Set user as admin for" : "کاربر را به عنوان مدیر تنظیم کنید",
    "Select user quota" : "سهمیه کاربر را انتخاب کنید",
    "Delete user" : "حذف کردن کاربر",
    "Wipe all devices" : "همه دستگاه ها را پاک کنید.",
    "Disable user" : "غیرفعال کردن کاربر",
    "Enable user" : "کاربر را فعال کنید",
    "Failed to update user manager" : "Failed to update user manager",
    "Toggle user actions menu" : "Toggle user actions menu",
    "User management settings" : "User management settings",
    "Show user backend" : "نمایش پس زمینه کاربر",
    "Send welcome email to new users" : "Send welcome email to new users",
    "Name your device" : "Name your device",
    "Server error while trying to add WebAuthn device" : "Server error while trying to add WebAuthn device",
    "by {author}\n{license}" : "by {author}\n{license}",
    "Active users" : "کاربران فعال",
    "Disabled users" : "کاربران غیرفعال شده است",
    "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "Not available as federation has been disabled for your account, contact your system administrator if you have any questions",
    "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions",
    "Show to logged in users only" : "نمایش فقط برای کاربران وارد شده به سامانه",
    "Nextcloud help resources" : "منابع راهنمای نکست‌کلود",
    "SMTP Username" : "نام کاربری SMTP",
    "Active accounts" : "حساب‌های فعال"
},
"nplurals=2; plural=(n > 1);");
